@@ -1,18 +1,32 @@
 from typing import Any, List
 from logging import getLogger
 import traceback
+from pydantic import Field
 
 import deeplabel.client
 from deeplabel.exceptions import InvalidCredentials
 import deeplabel.basemodel
+from deeplabel.basemodel import BaseModel, DeeplabelBase
 from typing import Dict
 
 logger = getLogger(__name__)
 
 
+class _UserEmail(BaseModel):
+   verified: bool
+   value: str 
+
+class UserAnnotation(DeeplabelBase):
+    """A custom User Subclass i.e., one that has only limited keys compared to 
+    User from deeplabel.auth.users with only `email` and `user_id` keys.
+    """
+
+    email: _UserEmail
+    user_id: str
+
 class UserToken(deeplabel.basemodel.DeeplabelBase):
 
-    userId: str
+    user: UserAnnotation = Field(None, alias='userId')
     hash: str
     expiry: str
     name: str
@@ -24,8 +38,8 @@ class UserToken(deeplabel.basemodel.DeeplabelBase):
     ):
         # Use client session so that non-default headers can be passed
         params = params={"name": "DEFAULT_TOKEN"}
-        resp = client.get(
-            "/users/tokens",
+        resp = client.session.get(
+            client.label_url.rstrip('/')+"/users/tokens",
             params=params,
             headers={"Authorization": f"Bearer {root_secret_key}"},
         )
