@@ -48,6 +48,7 @@ class BaseClient:
             url = self._get_url_by_caller(url)
         if self.restriction in ["false",False]:
             json["restriction"] = "false"
+        json["sessionRestriction"] = "false"
         response = self.session.post(
             url, json=json, headers={**self.headers, **(headers if isinstance(headers, dict) else {})})
         if response.status_code > 300:
@@ -109,6 +110,7 @@ class BaseClient:
             params["projectId"] = self.project_id  # type: ignore
         if self.restriction in ["false",False]:
             params["restriction"] = "false"
+        params["sessionRestriction"] = "false"
         if not url.startswith("http"):
             url = self._get_url_by_caller(url)
         logger.debug(f"Fetching {url} params: {params}")
@@ -125,6 +127,7 @@ class BaseClient:
             url = self._get_url_by_caller(url)
         if self.restriction in ["false",False]:
             json["restriction"] = "false"
+        json["sessionRestriction"] = "false"
         response = self.session.put(url, json=json, headers={**self.headers, **(headers if isinstance(headers, dict) else {})})
         if response.status_code > 202:
             logger.error(f"{response.status_code}  {url} failed. {response.text}")
