@@ -1,6 +1,6 @@
 import json
 import PIL.Image
-from typing import Type, Union
+from typing import Union
 import dataclasses
 import os
 from logging import getLogger
@@ -13,28 +13,34 @@ from deeplabel.label.gallery.images import Image
 import deeplabel.types.bounding_box as bounding_box
 import deeplabel.label.label_maps
 from deeplabel.contrib.utils import image_to_name
-from tqdm.contrib.concurrent import process_map
+from tqdm.contrib.concurrent import process_map  # type: ignore
 import deeplabel.label.videos
 import deeplabel.client
 from typing import List, Dict, Any, Tuple, Optional
 import numpy as np
-from deeplabel.contrib.downloaders.frame_downloader import GalleryImageDownloader, VideoAndFrameDownloader
-from deeplabel.exceptions import handle_deeplabel_exceptions
+from deeplabel.contrib.downloaders.frame_downloader import (
+    GalleryImageDownloader,
+    VideoAndFrameDownloader,
+)
+from deeplabel.exceptions import handle_deeplabel_exceptions  # type: ignore
 
 
 logger = getLogger(__name__)
 
+
 class BaseDoc(BaseModel):
     """Base For all docs with id key"""
+
     id: str
 
+
 class CocoImage(BaseDoc):
     url: str
     width: int
     height: int
     file_name: str
-    video_name:Optional[str]
-    video_id:Optional[str]
+    video_name: Optional[str]
+    video_id: Optional[str]
 
 
 class BaseCocoAnnotation(BaseDoc):
@@ -51,9 +57,11 @@ class DetectionCocoAnnotation(BaseCocoAnnotation):
 class SegmentationCocoAnnotation(BaseCocoAnnotation):
     segmentation: List[Any]
 
+
 class Category(BaseDoc):
     name: str
 
+
 class CocoDataset(BaseModel):
     categories: List[Category]
     annotations: List[Union[DetectionCocoAnnotation, SegmentationCocoAnnotation]]
@@ -66,30 +74,30 @@ class CocoGalleryExporter:
 
     root_dir: str
     client: deeplabel.client.BaseClient
-    categories_memo: Dict[str, Dict[str, Any]] = dataclasses.field(default_factory=dict)  # Mapping between label_id -> label
+    categories_memo: Dict[str, Dict[str, Any]] = dataclasses.field(
+        default_factory=dict
+    )  # Mapping between label_id -> label
 
     def __post_init__(self):
         os.makedirs(self.root_dir, exist_ok=True)
 
-    @handle_deeplabel_exceptions(lambda: ([],[]))
+    @handle_deeplabel_exceptions(lambda: ([], []))  # type: ignore
     def run(
         self,
         gallery: "deeplabel.label.gallery.Gallery",
-        ):
+    ):
         annotations: List[BaseCocoAnnotation] = []
         images: List[CocoImage] = []
         image_downloader = GalleryImageDownloader(gallery)
-        # Since each image is independent, it's faster to download them in parallel
-        images_to_download:List[Image] = []
         # List of Tuple, where each tuple has Image to download and it's output path
-        images_and_paths_to_download:List[Tuple[Image,str]] = []
-        os.makedirs(os.path.join(self.root_dir, 'images'), exist_ok=True)
+        images_and_paths_to_download: List[Tuple[Image, str]] = []
+        os.makedirs(os.path.join(self.root_dir, "images"), exist_ok=True)
         for image in gallery.images:
             if not image.detections:
                 logger.info(f"No detections for image {image.image_id}. Skipping")
                 continue  # skip empty frames
             image_name = image_to_name(image)
-            image_path = os.path.join(self.root_dir, 'images',image_name)
+            image_path = os.path.join(self.root_dir, "images", image_name)
             images_and_paths_to_download.append((image, image_path))
         image_downloader.download_parallel(images_and_paths_to_download)
         for image in gallery.images:
@@ -97,7 +105,7 @@ class CocoGalleryExporter:
                 logger.info(f"No detections for image {image.image_id}. Skipping")
                 continue  # skip empty frames
             image_name = image_to_name(image)
-            image_path = os.path.join(self.root_dir, 'images',image_name)
+            image_path = os.path.join(self.root_dir, "images", image_name)
             img = PIL.Image.open(image_path)
             images.append(
                 CocoImage(
@@ -129,7 +137,7 @@ class CocoGalleryExporter:
                         area=h * w,
                     )
                 elif detection.type == ImageDetectionType.polygon:
-                    poly = detection.polygon.to_shapely( #type: ignore
+                    poly = detection.polygon.to_shapely(  # type: ignore
                         scale_x=img.width, scale_y=img.height
                     )
                     annotation = SegmentationCocoAnnotation(
@@ -141,7 +149,9 @@ class CocoGalleryExporter:
                         image_id=image.image_id,
                     )
                 else:
-                    logger.info(f"Unsupported Detection Type: {detection.type} for image {image.image_id} for coco format.. Skipping")
+                    logger.debug(
+                        f"Unsupported Detection Type: {detection.type} for image {image.image_id} for coco format.. Skipping"
+                    )
                     continue
                 annotations.append(annotation)
         return images, annotations
@@ -153,12 +163,15 @@ class CocoVideoExporter:
 
     root_dir: str
     client: deeplabel.client.BaseClient
-    categories_memo: Dict[str, Dict[str, Any]] = dataclasses.field(default_factory=dict)  # Mapping between label_id -> label
+    categories_memo: Dict[str, Dict[str, Any]] = dataclasses.field(
+        default_factory=dict
+    )  # Mapping between label_id -> label
+    write_frames: bool = False
 
     def __post_init__(self):
         os.makedirs(self.root_dir, exist_ok=True)
 
-    @handle_deeplabel_exceptions(lambda: ([],[]))
+    @handle_deeplabel_exceptions(lambda: ([], []))
     def run(
         self,
         video: "deeplabel.label.videos.Video",
@@ -171,7 +184,8 @@ class CocoVideoExporter:
             if not frame.detections:
                 continue  # skip empty frames
             frame_path = os.path.join(self.root_dir, "images", frame.frame_id + ".jpg")
-            frame_downloader.download(frame, frame_path)
+            if self.write_frames:
+                frame_downloader.download(frame, frame_path)
             frames.append(
                 CocoImage(
                     id=frame.frame_id,
@@ -180,11 +194,11 @@ class CocoVideoExporter:
                     width=frame.resolution.width,
                     file_name=os.path.basename(frame_path),  # type:ignore
                     video_id=video.video_id,
-                    video_name=video.title
+                    video_name=video.title,
                 )
             )
             for detection in frame.detections:
-                if detection.type == VideoDetectionType.bounding_box and isinstance(
+                if detection.type == VideoDetectionType.BOUNDING_BOX and isinstance(
                     detection.bounding_box, bounding_box.BoundingBox
                 ):
                     bbox = detection.bounding_box
@@ -203,7 +217,7 @@ class CocoVideoExporter:
                         category_id=detection.label_id.label_id,
                         area=h * w,
                     )
-                elif detection.type == VideoDetectionType.polygon:
+                elif detection.type == VideoDetectionType.POLYGON:
                     poly = detection.polygon.to_shapely(
                         scale_x=frame.resolution.width, scale_y=frame.resolution.height
                     )
@@ -216,11 +230,12 @@ class CocoVideoExporter:
                         image_id=frame.frame_id,
                     )
                 else:
-                    logger.info(f"Unsupported Detection Type: {detection.type} for videoId {video.video_id} for coco format.. Skipping")
+                    logger.debug(
+                        f"Unsupported Detection Type: {detection.type} for videoId {video.video_id} for coco format.. Skipping"
+                    )
                     continue
                 annotations.append(annotation)
 
-
         return frames, annotations
 
 
@@ -228,26 +243,26 @@ class CocoVideoExporter:
 class CocoExporter:
     root_dir: str
     client: "deeplabel.client.BaseClient"
-    append:bool = True
+    append: bool = True
 
     def __post_init__(self):
         logger.info(f"Exporting in coco format to {self.root_dir}")
 
-    def get_existing_dataset(self, dataset_path)->CocoDataset:
+    def get_existing_dataset(self, dataset_path) -> CocoDataset:
         if os.path.exists(dataset_path):
-            with open(dataset_path, 'r') as f:
+            with open(dataset_path, "r") as f:
                 existing_dataset = json.load(f)
             existing_dataset = CocoDataset(**existing_dataset)
         else:
-            existing_dataset = CocoDataset(categories=[],annotations=[],images=[])
+            existing_dataset = CocoDataset(categories=[], annotations=[], images=[])
         return existing_dataset
-    
-    def dataset_path(self, folder:deeplabel.label.folders.RootFolder):
+
+    def dataset_path(self, folder: deeplabel.label.folders.RootFolder):
         """If the folder is a root folder, it represents the project root. So export as Project_Videos_Dataset_xxyyzz"""
         prefix = ""
         suffix = ""
         if type(folder) is deeplabel.label.folders.RootFolder:
-            prefix+= "Project_"
+            prefix += "Project_"
             suffix = folder.project_id
         else:
             prefix += "Folder_"
@@ -256,7 +271,7 @@ class CocoExporter:
             prefix += "Videos_"
         else:
             prefix += "Gallery_"
-        return prefix+suffix+'.json'
+        return prefix + suffix + ".json"
 
     def export(self, folder: deeplabel.label.folders.RootFolder):
         os.makedirs(self.root_dir, exist_ok=True)
@@ -265,34 +280,36 @@ class CocoExporter:
             exporter = CocoVideoExporter(root_dir=self.root_dir, client=self.client)
             fav = process_map(exporter.run, folder.videos)
             fav: List[
-                Tuple(List[CocoImage], List[BaseCocoAnnotation])
+                Tuple[List[CocoImage], List[BaseCocoAnnotation]]
             ]  # frames_and_annotations_per_video
         elif folder.type == deeplabel.label.folders.FolderType.GALLERY:
             exporter = CocoGalleryExporter(root_dir=self.root_dir, client=self.client)
             fav = process_map(exporter.run, folder.galleries)
-        
+
         # Serialize the images/annotations from per_video lists to a single list
         images, annotations = [], []
         for imgs, anns in fav:
             images.extend(imgs)
             annotations.extend(anns)
-        
+
         dataset = CocoDataset(
-            categories=categories,
-            annotations=annotations,
-            images = images
+            categories=categories, annotations=annotations, images=images
         )
-        
+
         # Either only keep the new images or append to existing images, annotations and categories
         dataset_path = os.path.join(self.root_dir, self.dataset_path(folder))
         if self.append:
             existing_dataset = self.get_existing_dataset(dataset_path)
             dataset = CocoDataset(
-                categories=self.merge_docs_by_id(existing_dataset.categories, dataset.categories),
-                annotations=self.merge_docs_by_id(existing_dataset.annotations, dataset.annotations),
-                images=self.merge_docs_by_id(existing_dataset.images, dataset.images)
+                categories=self.merge_docs_by_id(
+                    existing_dataset.categories, dataset.categories
+                ),
+                annotations=self.merge_docs_by_id(
+                    existing_dataset.annotations, dataset.annotations
+                ),
+                images=self.merge_docs_by_id(existing_dataset.images, dataset.images),
             )
-        
+
         with open(dataset_path, "w") as f:
             # exclude unset will skip the video_id and video_name in images if unset
             json.dump(dataset.dict(exclude_unset=True), f)
@@ -310,7 +327,7 @@ class CocoExporter:
         return categories
 
     @staticmethod
-    def merge_docs_by_id(old_many:List[BaseDoc], new_many:List[BaseDoc]):
+    def merge_docs_by_id(old_many: List[BaseDoc], new_many: List[BaseDoc]):
         """Given 2 set of Docs of same type, merge them, skipping old doc if it exists in new_many
 
         Args:
@@ -320,10 +337,7 @@ class CocoExporter:
         Returns:
             List[BaseDoc]: List of merged Docs
         """
-        new_memo = {
-            new_doc.id:new_doc
-            for new_doc in new_many
-        }
+        new_memo = {new_doc.id: new_doc for new_doc in new_many}
         # return existing document if it exists, else return from new doc
         to_keep = [doc for doc in old_many if doc.id not in new_memo]
         return [*new_many, *to_keep]
