@@ -1,19 +1,21 @@
 import os
+import deeplabel
 import functools
 from logging import getLogger, FileHandler, Formatter
-import coloredlogs
 import tempfile
-from importlib.metadata import version
 logger = getLogger(__name__)
 
 # Create an error logger specifically for logging unexpected errors to /tmp/deeplabel-sdk-errors.logs
 error_logger = getLogger('Error')
 error_logger.propagate = False
 log_file = os.path.join(tempfile.gettempdir(), 'deeplabel-sdk-errors.logs') 
+if not os.path.exists(log_file):
+    with open(log_file, 'w') as f:
+        f.write(f"Deeplabel-sdk version: {deeplabel.__version__}\n")
+    os.chmod(log_file, 0o777)
 error_file_handler=FileHandler(log_file)
 error_file_handler.setFormatter(Formatter('%(asctime)s %(name)s[%(process)d] %(levelname)s %(message)s'))
 error_logger.addHandler(error_file_handler)
-error_logger.error(f"deeplabel-sdk version: {version('deeplabel-sdk')}")
 
 # Root Exception Class for all Deeplabel related Exceptions
 class DeeplabelException(Exception):...
