@@ -1,5 +1,3 @@
-from dataclasses import dataclass
-from dataclasses_json import dataclass_json, LetterCase, Undefined, CatchAll
 from deeplabel.exceptions import InvalidIdError
 from deeplabel.basemodel import DeeplabelBase
 import deeplabel.client
@@ -9,7 +7,6 @@ class Notebook(DeeplabelBase):
     notebook_id: str
     name: str
     content: str
-    metadata: CatchAll
 
     @classmethod
     def from_notebook_id(cls, notebook_id: str, client: "deeplabel.client.BaseClient") -> "Notebook":  # type: ignore Used to ignore using private class BaseClient
