@@ -4,7 +4,7 @@ from  deeplabel.client import DeeplabelClient
 
 @pytest.fixture(scope="session")
 def client():
-    token = "Dt7xLMNH-87MRYsUv-pXZJKJsF-y80klrmO"
+    token = "insert token here"
     client = DeeplabelClient(token=token, restriction=False)
     return client
 
